@@ -86,6 +86,7 @@ public class HopVfs {
       fsm.addProvider("https", new org.apache.commons.vfs2.provider.https.HttpsFileProvider());
       fsm.addProvider("ftp", new org.apache.commons.vfs2.provider.ftp.FtpFileProvider());
       fsm.addProvider("ftps", new org.apache.commons.vfs2.provider.ftps.FtpsFileProvider());
+      fsm.addProvider("sftp", new org.apache.commons.vfs2.provider.sftp.SftpFileProvider());
       fsm.addProvider("war", new org.apache.commons.vfs2.provider.jar.JarFileProvider());
       fsm.addProvider("par", new org.apache.commons.vfs2.provider.jar.JarFileProvider());
       fsm.addProvider("ear", new org.apache.commons.vfs2.provider.jar.JarFileProvider());
@@ -472,7 +473,9 @@ public class HopVfs {
     return files;
   }
 
-  /** @see StandardFileSystemManager#freeUnusedResources() */
+  /**
+   * @see StandardFileSystemManager#freeUnusedResources()
+   */
   public static void freeUnusedResources() {
     if (fsm != null) {
       fsm.freeUnusedResources();
