@@ -33,7 +33,6 @@ import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.ITransformData;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
 
@@ -43,10 +42,9 @@ import static org.apache.hop.core.Const.*;
 
 /**
  * This class is supposed to use in transforms where the mapping to sub pipelines takes place
- *
  */
 public abstract class TransformWithMappingMeta<Main extends ITransform, Data extends ITransformData>
-    extends BaseTransformMeta implements ITransformMeta<Main, Data> {
+    extends BaseTransformMeta<Main, Data> {
 
   private static final Class<?> PKG = TransformWithMappingMeta.class; // For Translator
 
@@ -306,15 +304,15 @@ public abstract class TransformWithMappingMeta<Main extends ITransform, Data ext
     return type.equals("Pipeline")
         ? isPipelineInternalVariable(variableName)
         : type.equals("Workflow")
-            ? isJobInternalVariable(variableName)
-            : isJobInternalVariable(variableName) || isPipelineInternalVariable(variableName);
+            ? isWorkflowInternalVariable(variableName)
+            : isWorkflowInternalVariable(variableName) || isPipelineInternalVariable(variableName);
   }
 
   private static boolean isPipelineInternalVariable(String variableName) {
-    return (Arrays.asList(Const.INTERNAL_PIPELINE_VARIABLES).contains(variableName));
+    return Const.INTERNAL_PIPELINE_VARIABLES.contains(variableName);
   }
 
-  private static boolean isJobInternalVariable(String variableName) {
-    return (Arrays.asList(Const.INTERNAL_WORKFLOW_VARIABLES).contains(variableName));
+  private static boolean isWorkflowInternalVariable(String variableName) {
+    return Const.INTERNAL_WORKFLOW_VARIABLES.contains(variableName);
   }
 }
