@@ -20,7 +20,6 @@ package org.apache.hop.pipeline.engines.remote;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.vfs2.FileObject;
 import org.apache.hop.core.Const;
-import org.apache.hop.core.HopVariablesList;
 import org.apache.hop.core.IRowSet;
 import org.apache.hop.core.Result;
 import org.apache.hop.core.exception.HopException;
@@ -29,6 +28,8 @@ import org.apache.hop.core.metadata.SerializableMetadataProvider;
 import org.apache.hop.core.parameters.*;
 import org.apache.hop.core.row.RowBuffer;
 import org.apache.hop.core.util.Utils;
+import org.apache.hop.core.variables.VariableRegistry;
+import org.apache.hop.core.variables.VariableScope;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.core.vfs.HopVfs;
@@ -253,6 +254,14 @@ public class RemotePipelineEngine extends Variables implements IPipelineEngine<P
 
     executionConfiguration.getVariablesMap().putAll(vars);
 
+    // Add parameters to the executionConfiguration
+    Map<String, String> params = new HashMap<>();
+    for (String param : listParameters()) {
+        params.put(param, getVariable(param));
+    }
+
+    executionConfiguration.getParametersMap().putAll(params);
+
     hopServer.getLogChannel().setLogLevel(executionConfiguration.getLogLevel());
 
     try {
@@ -350,55 +359,37 @@ public class RemotePipelineEngine extends Variables implements IPipelineEngine<P
     }
   }
 
-  public static boolean isVariablePassedToRemoteServer(String var) {
-    if (StringUtils.isEmpty(var)) {
+  public static boolean isVariablePassedToRemoteServer(String variableName) {
+    if (StringUtils.isEmpty(variableName)) {
       return false;
     }
     // JRE/JVM stuff
-    if (var.startsWith("java.")
-        || var.startsWith("file.")
-        || var.startsWith("awt.")
-        || var.startsWith("line.")
-        || var.startsWith("org.eclipse.")
-        || var.startsWith("sun.")
-        || var.startsWith("user.")
-        || var.startsWith("os.")
-        || var.startsWith("path.separator")
-        || var.startsWith("javax.")) {
+    if (variableName.startsWith("java.")
+        || variableName.startsWith("file.")
+        || variableName.startsWith("awt.")
+        || variableName.startsWith("line.")
+        || variableName.startsWith("org.eclipse.")
+        || variableName.startsWith("sun.")
+        || variableName.startsWith("user.")
+        || variableName.startsWith("os.")
+        || variableName.startsWith("path.separator")
+        || variableName.startsWith("javax.")) {
       return false;
     }
     // Internal variables get resolved automatically
-    if (Const.indexOfString(var, Const.INTERNAL_WORKFLOW_VARIABLES) >= 0) {
+    if (Const.INTERNAL_WORKFLOW_VARIABLES.contains(variableName)) {
       return false;
     }
-    if (Const.indexOfString(var, Const.INTERNAL_PIPELINE_VARIABLES) >= 0) {
+    if (Const.INTERNAL_PIPELINE_VARIABLES.contains(variableName)) {
       return false;
     }
     // These are used at startup and shouldn't have an effect at runtime.
     // e.g. to be configured on the server
     //
-    if (HopVariablesList.getInstance().getVariablesSet().contains(var)) {
+    if (VariableRegistry.getInstance().getVariableNames(VariableScope.SYSTEM, VariableScope.APPLICATION).contains(variableName)) {
       return false;
     }
-    if (var.equals(Const.HOP_CONFIG_FOLDER)) {
-      return false;
-    }
-    if (var.equals(Const.HOP_AUDIT_FOLDER)) {
-      return false;
-    }
-    if (var.equals(Const.HOP_PLATFORM_OS)) {
-      return false;
-    }
-    if (var.equals(Const.HOP_PLATFORM_RUNTIME)) {
-      return false;
-    }
-    if (var.equals(Const.HOP_SHARED_JDBC_FOLDER)) {
-      return false;
-    }
-    if (var.equals(Const.HOP_SIMPLE_STACK_TRACES)) {
-      return false;
-    }
-    if (var.equals("LOG_PATH")) {
+    if (variableName.equals("LOG_PATH")) {
       return false;
     }
 
