@@ -37,7 +37,7 @@ import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.errorhandling.IStream;
+import org.apache.hop.pipeline.transform.stream.IStream;
 import org.apache.hop.pipeline.transforms.missing.Missing;
 import org.apache.hop.resource.*;
 import org.w3c.dom.Document;
@@ -374,21 +374,21 @@ public class TransformMeta
   }
 
   public boolean hasChanged() {
-    ITransformMeta bsi = this.getTransform();
-    return bsi != null ? bsi.hasChanged() : false;
+    ITransformMeta meta = this.getTransform();
+    return meta != null ? meta.hasChanged() : false;
   }
 
   public void setChanged(boolean ch) {
-    BaseTransformMeta bsi = (BaseTransformMeta) this.getTransform();
-    if (bsi != null) {
-      bsi.setChanged(ch);
+    BaseTransformMeta<?,?> meta = (BaseTransformMeta<?,?>) this.getTransform();
+    if (meta != null) {
+      meta.setChanged(ch);
     }
   }
 
   public void setChanged() {
-    ITransformMeta bsi = this.getTransform();
-    if (bsi != null) {
-      bsi.setChanged();
+    ITransformMeta meta = this.getTransform();
+    if (meta != null) {
+      meta.setChanged();
     }
   }
 
@@ -550,7 +550,6 @@ public class TransformMeta
     return location;
   }
 
-  @SuppressWarnings("deprecation")
   public void check(
       List<ICheckResult> remarks,
       PipelineMeta pipelineMeta,
@@ -702,7 +701,6 @@ public class TransformMeta
   }
 
   @Override
-  @SuppressWarnings("deprecation")
   public String exportResources(
       IVariables variables,
       Map<String, ResourceDefinition> definitions,
