@@ -24,7 +24,6 @@ import com.sun.jersey.api.client.config.ClientConfig;
 import com.sun.jersey.api.client.config.DefaultClientConfig;
 import com.sun.jersey.api.client.filter.HTTPBasicAuthFilter;
 import com.sun.jersey.api.json.JSONConfiguration;
-import org.apache.commons.cli.ParseException;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.vfs2.FileObject;
 import org.apache.hop.core.Const;
@@ -42,6 +41,7 @@ import org.apache.hop.core.logging.ILogChannel;
 import org.apache.hop.core.logging.LogChannel;
 import org.apache.hop.core.logging.LogLevel;
 import org.apache.hop.core.plugins.IPlugin;
+import org.apache.hop.core.plugins.JarCache;
 import org.apache.hop.core.plugins.PluginRegistry;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
@@ -59,10 +59,10 @@ import org.w3c.dom.Node;
 import picocli.CommandLine;
 import picocli.CommandLine.Parameters;
 
-import java.io.IOException;
 import java.util.Date;
 import java.util.List;
 import java.util.Map;
+import java.util.stream.Stream;
 
 public class HopServer implements Runnable, IHasHopMetadataProvider {
   private static final Class<?> PKG = HopServer.class; // For Translator
@@ -435,13 +435,18 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
     }
   }
 
-  private void buildVariableSpace() throws IOException {
+  private void buildVariableSpace() {
     // Also grabs the system properties from hop.config.
     //
     variables = Variables.getADefaultVariableSpace();
   }
 
   public static void main(String[] args) {
+    String[] arguments =
+        Stream.of(args)
+            .flatMap(a -> Stream.of(a.split("(?=--)")))
+            .filter(a -> !a.isEmpty())
+            .toArray(String[]::new);
 
     HopServer hopServer = new HopServer();
 
@@ -449,7 +454,6 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
       // Create the command line options...
       //
       picocli.CommandLine cmd = new picocli.CommandLine(hopServer);
-
       // Apply the system properties to the JVM
       //
       hopServer.applySystemProperties();
@@ -463,6 +467,10 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
       //
       hopServer.buildVariableSpace();
 
+      // Clear the jar file cache so that we don't waste memory...
+      //
+      JarCache.getInstance().clear();
+
       // Set up the metadata to use
       //
       hopServer.metadataProvider =
@@ -487,7 +495,7 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
 
       // This will calculate the option values and put them in HopRun or the plugin classes
       //
-      picocli.CommandLine.ParseResult parseResult = cmd.parseArgs(args);
+      picocli.CommandLine.ParseResult parseResult = cmd.parseArgs(arguments);
 
       if (picocli.CommandLine.printHelpIfRequested(parseResult)) {
         printExtraUsageExamples();
@@ -578,13 +586,12 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
    * @param port
    * @param username
    * @param password
-   * @throws ParseException
    * @throws HopServerCommandException
    */
   @VisibleForTesting
   static void callStopHopServerRestService(
       String hostname, String port, String username, String password)
-      throws ParseException, HopServerCommandException {
+      throws HopServerCommandException {
     // get information about the remote connection
     try {
       HopClientEnvironment.init();
@@ -624,8 +631,6 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
   public static class HopServerCommandException extends Exception {
     private static final long serialVersionUID = 1L;
 
-    public HopServerCommandException() {}
-
     public HopServerCommandException(final String message) {
       super(message);
     }
@@ -633,10 +638,6 @@ public class HopServer implements Runnable, IHasHopMetadataProvider {
     public HopServerCommandException(final String message, final Throwable cause) {
       super(message, cause);
     }
-
-    public HopServerCommandException(final Throwable cause) {
-      super(cause);
-    }
   }
 
   /**
