@@ -38,7 +38,7 @@ public class CompressionProviderFactoryTest {
   @BeforeClass
   public static void setUpBeforeClass() throws Exception {
     PluginRegistry.addPluginType(CompressionPluginType.getInstance());
-    PluginRegistry.init(false);
+    PluginRegistry.init();
   }
 
   @AfterClass
