@@ -61,7 +61,6 @@ import org.jboss.jandex.DotName;
 import org.jboss.jandex.IndexView;
 
 import java.io.File;
-import java.io.IOException;
 import java.util.*;
 
 public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngineRunConfiguration> {
@@ -504,7 +503,7 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
     }
   }
 
-  private void validateTransformBeamUsage(ITransformMeta<?,?> meta) throws HopException {
+  private void validateTransformBeamUsage(ITransformMeta meta) throws HopException {
     if (meta instanceof GroupByMeta) {
       throw new HopException(
           "Group By is not supported.  Use the Memory Group By transform instead.  It comes closest to Beam functionality.");
