@@ -35,10 +35,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.metadata.api.IHopMetadataSerializer;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.List;
@@ -52,8 +50,7 @@ import java.util.Map;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.BigData",
     keywords = "i18n::BeamInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/beaminput.html")
-public class BeamInputMeta extends BaseTransformMeta
-    implements ITransformMeta<BeamInput, BeamInputData>, IBeamPipelineTransformHandler {
+public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> implements IBeamPipelineTransformHandler {
 
   @HopMetadataProperty(key = "input_location")
   private String inputLocation;
@@ -63,21 +60,6 @@ public class BeamInputMeta extends BaseTransformMeta
 
   public BeamInputMeta() {}
 
-  @Override
-  public BeamInput createTransform(
-      TransformMeta transformMeta,
-      BeamInputData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new BeamInput(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public BeamInputData getTransformData() {
-    return new BeamInputData();
-  }
-
   @Override
   public String getDialogClassName() {
     return BeamInputDialog.class.getName();
