@@ -36,10 +36,8 @@ import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.dummy.DummyData;
 
@@ -55,8 +53,7 @@ import java.util.Map;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.BigData",
     keywords = "i18n::BeamConsumeMeta.keyword",
     documentationUrl = "/pipeline/transforms/beamkafkaconsume.html")
-public class BeamConsumeMeta extends BaseTransformMeta
-    implements ITransformMeta<BeamConsume, DummyData>, IBeamPipelineTransformHandler {
+public class BeamConsumeMeta extends BaseTransformMeta<BeamConsume, DummyData> implements IBeamPipelineTransformHandler {
 
   @HopMetadataProperty private String topics;
 
@@ -115,21 +112,6 @@ public class BeamConsumeMeta extends BaseTransformMeta
     configOptions = new ArrayList<>();
   }
 
-  @Override
-  public BeamConsume createTransform(
-      TransformMeta transformMeta,
-      DummyData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new BeamConsume(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public DummyData getTransformData() {
-    return new DummyData();
-  }
-
   @Override
   public String getDialogClassName() {
     return BeamConsumeDialog.class.getName();
