@@ -20,7 +20,6 @@ package org.apache.hop.beam.transforms.kafka;
 import org.apache.avro.Schema;
 import org.apache.avro.generic.GenericRecord;
 import org.apache.beam.sdk.coders.AvroCoder;
-import org.apache.beam.sdk.coders.AvroGenericCoder;
 import org.apache.beam.sdk.values.PCollection;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.transform.BeamKafkaOutputTransform;
@@ -37,10 +36,8 @@ import org.apache.hop.core.row.value.ValueMetaAvroRecord;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.dummy.DummyData;
 
@@ -56,8 +53,7 @@ import java.util.Map;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.BigData",
     keywords = "i18n::BeamProduceMeta.keyword",
     documentationUrl = "/pipeline/transforms/beamkafkaproduce.html")
-public class BeamProduceMeta extends BaseTransformMeta
-    implements ITransformMeta<BeamProduce, DummyData>, IBeamPipelineTransformHandler {
+public class BeamProduceMeta extends BaseTransformMeta<BeamProduce, DummyData> implements IBeamPipelineTransformHandler {
 
   @HopMetadataProperty(key = "bootstrap_servers")
   private String bootstrapServers;
@@ -81,21 +77,6 @@ public class BeamProduceMeta extends BaseTransformMeta
     configOptions = new ArrayList<>();
   }
 
-  @Override
-  public BeamProduce createTransform(
-      TransformMeta transformMeta,
-      DummyData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new BeamProduce(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public DummyData getTransformData() {
-    return new DummyData();
-  }
-
   @Override
   public String getDialogClassName() {
     return BeamProduceDialog.class.getName();
