@@ -33,7 +33,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.ArrayList;
@@ -44,8 +43,7 @@ import java.util.Map;
  * Class providing an output transform for writing data to a cassandra table. Can create the
  * specified table (if it doesn't already exist) and can update table meta data.
  */
-public class CassandraOutput extends BaseTransform<CassandraOutputMeta, CassandraOutputData>
-    implements ITransform<CassandraOutputMeta, CassandraOutputData> {
+public class CassandraOutput extends BaseTransform<CassandraOutputMeta, CassandraOutputData> {
 
   public CassandraOutput(
       TransformMeta transformMeta,
