@@ -66,6 +66,7 @@ import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
 import org.eclipse.swt.widgets.*;
 import org.neo4j.driver.*;
+import org.neo4j.driver.Record;
 import org.neo4j.driver.types.Node;
 import org.neo4j.driver.types.Path;
 
@@ -746,7 +747,7 @@ public class HopNeo4jPerspective implements IHopPerspective {
     if (!LoggingCore.isEnabled(variables)) {
       return null;
     }
-    String connectionName = variables.getVariable(Defaults.VARIABLE_NEO4J_LOGGING_CONNECTION);
+    String connectionName = variables.getVariable(Defaults.NEO4J_LOGGING_CONNECTION);
 
     final NeoConnection connection =
         LoggingCore.getConnection(hopGui.getMetadataProvider(), variables);
