@@ -27,7 +27,6 @@ import org.apache.hop.neo4j.core.value.ValueMetaGraph;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.io.File;
@@ -38,8 +37,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-public class GenerateCsv extends BaseTransform<GenerateCsvMeta, GenerateCsvData>
-    implements ITransform<GenerateCsvMeta, GenerateCsvData> {
+public class GenerateCsv extends BaseTransform<GenerateCsvMeta, GenerateCsvData> {
 
   /**
    * This is the base transform that forms that basis for all transform. You can derive from this
