@@ -18,20 +18,13 @@
 package org.apache.hop.neo4j.transforms.importer;
 
 import org.apache.hop.core.annotations.Transform;
-import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
-import org.apache.hop.core.exception.HopXmlException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.variables.IVariables;
-import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
-import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.w3c.dom.Node;
 
 @Transform(
     id = "Neo4jImport",
@@ -41,8 +34,7 @@ import org.w3c.dom.Node;
     categoryDescription = "i18n::ImporterMeta.categoryDescription",
     keywords = "i18n::ImporterMeta.keyword",
     documentationUrl = "/pipeline/transforms/neo4j-import.html")
-public class ImporterMeta extends BaseTransformMeta
-    implements ITransformMeta<Importer, ImporterData> {
+public class ImporterMeta extends BaseTransformMeta<Importer, ImporterData> {
 
   @HopMetadataProperty(key = "filename_field_name")
   protected String filenameField;
@@ -141,21 +133,6 @@ public class ImporterMeta extends BaseTransformMeta
     // No fields are added by default
   }
 
-  @Override
-  public Importer createTransform(
-      TransformMeta transformMeta,
-      ImporterData iTransformData,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new Importer(transformMeta, this, iTransformData, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public ImporterData getTransformData() {
-    return new ImporterData();
-  }
-
   /**
    * Gets filenameField
    *
