@@ -35,11 +35,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransform;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.textfileoutput.TextFileField;
 import org.apache.hop.pipeline.transforms.textfileoutput.TextFileOutputMeta;
@@ -53,13 +50,12 @@ import java.util.List;
 @Transform(
     id = "ConcatFields",
     image = "concatfields.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.ConcatFields",
-    description = "i18n::BaseTransform.TypeTooltipDesc.ConcatFields",
+    name = "i18n::ConcatFields.Name",
+    description = "i18n::ConcatFields.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Transform",
     keywords = "i18n::ConcatFieldsMeta.keyword",
     documentationUrl = "/pipeline/transforms/concatfields.html")
-public class ConcatFieldsMeta extends BaseTransformMeta
-    implements ITransformMeta<ConcatFields, ConcatFieldsData> {
+public class ConcatFieldsMeta extends BaseTransformMeta<ConcatFields, ConcatFieldsData> {
 
   private static final Class<?> PKG = ConcatFieldsMeta.class; // For Translator
 
@@ -422,21 +418,6 @@ public class ConcatFieldsMeta extends BaseTransformMeta
     outputFields = new TextFileField[nrFields];
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      ConcatFieldsData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new ConcatFields(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public ConcatFieldsData getTransformData() {
-    return new ConcatFieldsData();
-  }
-
   public void setSpecifyingFormat(boolean specifyingFormat) {
     this.specifyingFormat = specifyingFormat;
   }
