@@ -38,7 +38,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.sql.SQLException;
@@ -46,8 +45,7 @@ import java.sql.Statement;
 import java.util.*;
 
 /** Manages a slowly changing dimension (lookup or update) */
-public class DimensionLookup extends BaseTransform<DimensionLookupMeta, DimensionLookupData>
-    implements ITransform<DimensionLookupMeta, DimensionLookupData> {
+public class DimensionLookup extends BaseTransform<DimensionLookupMeta, DimensionLookupData> {
 
   private static final Class<?> PKG = DimensionLookupMeta.class; // For Translator
 
