@@ -39,11 +39,9 @@ import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.DatabaseImpact;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformData;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -59,8 +57,8 @@ import java.util.*;
 @Transform(
     id = "DimensionLookup",
     image = "dimensionlookup.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.DimensionUpdate",
-    description = "i18n::BaseTransform.TypeTooltipDesc.DimensionUpdate",
+    name = "i18n::DimensionUpdate.Name",
+    description = "i18n::DimensionUpdate.Description",
     categoryDescription =
         "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.DataWarehouse",
     keywords = "i18n::DimensionLookupMeta.keyword",
@@ -68,8 +66,8 @@ import java.util.*;
 @InjectionSupported(
     localizationPrefix = "DimensionLookup.Injection.",
     groups = {"KEYS", "FIELDS"})
-public class DimensionLookupMeta extends BaseTransformMeta
-    implements ITransformMeta<DimensionLookup, DimensionLookupData>, IProvidesModelerMeta {
+public class DimensionLookupMeta extends BaseTransformMeta<DimensionLookup, DimensionLookupData>
+    implements IProvidesModelerMeta {
   private static final Class<?> PKG = DimensionLookupMeta.class; // For Translator
 
   public static final int TYPE_UPDATE_DIM_INSERT = 0;
@@ -1786,21 +1784,6 @@ public class DimensionLookupMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public DimensionLookup createTransform(
-      TransformMeta transformMeta,
-      DimensionLookupData data,
-      int cnr,
-      PipelineMeta tr,
-      Pipeline pipeline) {
-    return new DimensionLookup(transformMeta, this, data, cnr, tr, pipeline);
-  }
-
-  @Override
-  public DimensionLookupData getTransformData() {
-    return new DimensionLookupData();
-  }
-
   /** @return the schemaName */
   @Override
   public String getSchemaName() {
