@@ -21,19 +21,16 @@ import org.apache.commons.vfs2.FileObject;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.ResultFile;
 import org.apache.hop.core.exception.HopException;
-import org.apache.hop.core.exception.HopFileException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.util.Utils;
-import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.workarounds.BufferedOutputStreamWithCloseDetection;
 import org.apache.poi.common.usermodel.HyperlinkType;
@@ -51,8 +48,7 @@ import java.io.BufferedOutputStream;
 import java.io.IOException;
 
 public class ExcelWriterTransform
-    extends BaseTransform<ExcelWriterTransformMeta, ExcelWriterTransformData>
-    implements ITransform<ExcelWriterTransformMeta, ExcelWriterTransformData> {
+    extends BaseTransform<ExcelWriterTransformMeta, ExcelWriterTransformData> {
 
   private static final Class<?> PKG = ExcelWriterTransformMeta.class; // For Translator
 
@@ -222,35 +218,33 @@ public class ExcelWriterTransform
       if (parentfolder.exists()) {
         if (isDetailed()) {
           logDetailed(
-                  BaseMessages.getString(
-                          PKG,
-                          "ExcelWriter.Log.ParentFolderExist",
-                          HopVfs.getFriendlyURI(parentfolder)));
+              BaseMessages.getString(
+                  PKG, "ExcelWriter.Log.ParentFolderExist", HopVfs.getFriendlyURI(parentfolder)));
         }
       } else {
         if (isDetailed()) {
           logDetailed(
-                  BaseMessages.getString(
-                          PKG,
-                          "ExcelWriter.Log.ParentFolderNotExist",
-                          HopVfs.getFriendlyURI(parentfolder)));
+              BaseMessages.getString(
+                  PKG,
+                  "ExcelWriter.Log.ParentFolderNotExist",
+                  HopVfs.getFriendlyURI(parentfolder)));
         }
         if (meta.getFile().isCreateParentFolder()) {
           parentfolder.createFolder();
           if (isDetailed()) {
             logDetailed(
-                    BaseMessages.getString(
-                            PKG,
-                            "ExcelWriter.Log.ParentFolderCreated",
-                            HopVfs.getFriendlyURI(parentfolder)));
+                BaseMessages.getString(
+                    PKG,
+                    "ExcelWriter.Log.ParentFolderCreated",
+                    HopVfs.getFriendlyURI(parentfolder)));
           }
         } else {
           throw new HopException(
-                  BaseMessages.getString(
-                          PKG,
-                          "ExcelWriter.Log.ParentFolderNotExistCreateIt",
-                          HopVfs.getFriendlyURI(parentfolder),
-                          HopVfs.getFriendlyURI(filename)));
+              BaseMessages.getString(
+                  PKG,
+                  "ExcelWriter.Log.ParentFolderNotExistCreateIt",
+                  HopVfs.getFriendlyURI(parentfolder),
+                  HopVfs.getFriendlyURI(filename)));
         }
       }
     } finally {
@@ -681,7 +675,8 @@ public class ExcelWriterTransform
 
       data.file = HopVfs.getFileObject(buildFilename);
 
-      if (!HopVfs.getFileObject(buildFilename).getParent().exists() && meta.getFile().isCreateParentFolder()) {
+      if (!HopVfs.getFileObject(buildFilename).getParent().exists()
+          && meta.getFile().isCreateParentFolder()) {
         logDebug("Create parent directory for " + buildFilename + " because it does not exist.");
         createParentFolder(buildFilename);
       }
@@ -702,7 +697,6 @@ public class ExcelWriterTransform
         throw new HopException("Could not delete stale file " + buildFilename);
       }
 
-
       // adding filename to result
       if (meta.isAddToResultFilenames()) {
         // Add this to the result file names...
