@@ -26,15 +26,13 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineHopMeta;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.apache.hop.pipeline.transform.errorhandling.IStream;
+import org.apache.hop.pipeline.transform.stream.IStream;
 
 import java.util.List;
 
 /** Filters input rows base on conditions. */
-public class FilterRows extends BaseTransform<FilterRowsMeta, FilterRowsData>
-    implements ITransform<FilterRowsMeta, FilterRowsData> {
+public class FilterRows extends BaseTransform<FilterRowsMeta, FilterRowsData> {
 
   private static final Class<?> PKG = FilterRowsMeta.class; // For Translator
 
