@@ -39,7 +39,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.Iterator;
@@ -48,8 +47,7 @@ import java.util.Iterator;
  * Performs a fuzzy match for each main stream field row An approximative match is done in a lookup
  * stream
  */
-public class FuzzyMatch extends BaseTransform<FuzzyMatchMeta, FuzzyMatchData>
-    implements ITransform<FuzzyMatchMeta, FuzzyMatchData> {
+public class FuzzyMatch extends BaseTransform<FuzzyMatchMeta, FuzzyMatchData> {
   private static final Class<?> PKG = FuzzyMatchMeta.class; // For Translator
 
   public FuzzyMatch(
