@@ -33,13 +33,15 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.*;
-import org.apache.hop.pipeline.transform.errorhandling.IStream;
-import org.apache.hop.pipeline.transform.errorhandling.IStream.StreamType;
-import org.apache.hop.pipeline.transform.errorhandling.Stream;
-import org.apache.hop.pipeline.transform.errorhandling.StreamIcon;
+import org.apache.hop.pipeline.transform.BaseTransformMeta;
+import org.apache.hop.pipeline.transform.ITransformIOMeta;
+import org.apache.hop.pipeline.transform.TransformIOMeta;
+import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.pipeline.transform.stream.IStream;
+import org.apache.hop.pipeline.transform.stream.IStream.StreamType;
+import org.apache.hop.pipeline.transform.stream.Stream;
+import org.apache.hop.pipeline.transform.stream.StreamIcon;
 import org.w3c.dom.Node;
 
 import java.util.List;
@@ -47,13 +49,12 @@ import java.util.List;
 @Transform(
     id = "FuzzyMatch",
     image = "fuzzymatch.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.FuzzyMatch",
-    description = "i18n::BaseTransform.TypeTooltipDesc.FuzzyMatch",
+    name = "i18n::FuzzyMatch.Name",
+    description = "i18n::FuzzyMatch.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Lookup",
     keywords = "i18n::FuzzyMatchMeta.keyword",
     documentationUrl = "/pipeline/transforms/fuzzymatch.html")
-public class FuzzyMatchMeta extends BaseTransformMeta
-    implements ITransformMeta<FuzzyMatch, FuzzyMatchData> {
+public class FuzzyMatchMeta extends BaseTransformMeta<FuzzyMatch, FuzzyMatchData> {
   private static final Class<?> PKG = FuzzyMatchMeta.class; // For Translator
 
   public static final String DEFAULT_SEPARATOR = ",";
@@ -696,21 +697,6 @@ public class FuzzyMatchMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public FuzzyMatch createTransform(
-      TransformMeta transformMeta,
-      FuzzyMatchData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new FuzzyMatch(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public FuzzyMatchData getTransformData() {
-    return new FuzzyMatchData();
-  }
-
   @Override
   public boolean excludeFromRowLayoutVerification() {
     return true;
