@@ -33,7 +33,6 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.file.BaseFileInputTransform;
 import org.apache.hop.pipeline.transforms.file.IBaseFileInputReader;
@@ -51,8 +50,7 @@ import java.util.BitSet;
  * Read Json files, parse them and convert them to rows and writes these to one or more output
  * streams.
  */
-public class JsonInput extends BaseFileInputTransform<JsonInputMeta, JsonInputData>
-    implements ITransform<JsonInputMeta, JsonInputData> {
+public class JsonInput extends BaseFileInputTransform<JsonInputMeta, JsonInputData> {
   private static final Class<?> PKG = JsonInputMeta.class; // For Translator
 
   private RowOutputConverter rowOutputConverter;
