@@ -30,11 +30,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransform;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -44,12 +41,12 @@ import java.util.List;
 @Transform(
     id = "Mail",
     image = "mail.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.Mail",
-    description = "i18n::BaseTransform.TypeTooltipDesc.Mail",
+    name = "i18n::Mail.Name",
+    description = "i18n::Mail.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Utility",
     keywords = "i18n::MailMeta.keyword",
     documentationUrl = "/pipeline/transforms/mail.html")
-public class MailMeta extends BaseTransformMeta implements ITransformMeta<Mail, MailData> {
+public class MailMeta extends BaseTransformMeta<Mail, MailData> {
   private static final Class<?> PKG = MailMeta.class; // For Translator
 
   private String server;
@@ -163,16 +160,6 @@ public class MailMeta extends BaseTransformMeta implements ITransformMeta<Mail,
     return retval;
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      MailData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new Mail(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   public void allocate(int value) {
     this.embeddedimages = new String[value];
     this.contentids = new String[value];
@@ -964,11 +951,6 @@ public class MailMeta extends BaseTransformMeta implements ITransformMeta<Mail,
     this.messageOutputField = messageOutputField;
   }
 
-  @Override
-  public MailData getTransformData() {
-    return new MailData();
-  }
-
   @Override
   public boolean supportsErrorHandling() {
     return true;
