@@ -29,7 +29,6 @@ import org.apache.hop.core.injection.InjectionSupported;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowMeta;
-import org.apache.hop.core.row.value.ValueMetaBase;
 import org.apache.hop.core.row.value.ValueMetaFactory;
 import org.apache.hop.core.row.value.ValueMetaNone;
 import org.apache.hop.core.util.Utils;
@@ -37,10 +36,8 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -52,14 +49,13 @@ import java.util.List;
 @Transform(
     id = "MemoryGroupBy",
     image = "memorygroupby.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.MemoryGroupBy",
-    description = "i18n::BaseTransform.TypeTooltipDesc.MemoryGroupBy",
+    name = "i18n::MemoryGroupBy.Name",
+    description = "i18n::MemoryGroupBy.Description",
     categoryDescription =
         "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Statistics",
     keywords = "i18n::MemoryGroupByMeta.keyword",
     documentationUrl = "/pipeline/transforms/memgroupby.html")
-public class MemoryGroupByMeta extends BaseTransformMeta
-    implements ITransformMeta<MemoryGroupBy, MemoryGroupByData> {
+public class MemoryGroupByMeta extends BaseTransformMeta<MemoryGroupBy, MemoryGroupByData> {
   private static final Class<?> PKG = MemoryGroupByMeta.class; // For Translator
 
   public static final int TYPE_GROUP_NONE = 0;
@@ -165,52 +161,72 @@ public class MemoryGroupByMeta extends BaseTransformMeta
     super(); // allocate BaseTransformMeta
   }
 
-  /** @return Returns the aggregateField. */
+  /**
+   * @return Returns the aggregateField.
+   */
   public String[] getAggregateField() {
     return aggregateField;
   }
 
-  /** @param aggregateField The aggregateField to set. */
+  /**
+   * @param aggregateField The aggregateField to set.
+   */
   public void setAggregateField(String[] aggregateField) {
     this.aggregateField = aggregateField;
   }
 
-  /** @return Returns the aggregateType. */
+  /**
+   * @return Returns the aggregateType.
+   */
   public int[] getAggregateType() {
     return aggregateType;
   }
 
-  /** @param aggregateType The aggregateType to set. */
+  /**
+   * @param aggregateType The aggregateType to set.
+   */
   public void setAggregateType(int[] aggregateType) {
     this.aggregateType = aggregateType;
   }
 
-  /** @return Returns the groupField. */
+  /**
+   * @return Returns the groupField.
+   */
   public String[] getGroupField() {
     return groupField;
   }
 
-  /** @param groupField The groupField to set. */
+  /**
+   * @param groupField The groupField to set.
+   */
   public void setGroupField(String[] groupField) {
     this.groupField = groupField;
   }
 
-  /** @return Returns the subjectField. */
+  /**
+   * @return Returns the subjectField.
+   */
   public String[] getSubjectField() {
     return subjectField;
   }
 
-  /** @param subjectField The subjectField to set. */
+  /**
+   * @param subjectField The subjectField to set.
+   */
   public void setSubjectField(String[] subjectField) {
     this.subjectField = subjectField;
   }
 
-  /** @return Returns the valueField. */
+  /**
+   * @return Returns the valueField.
+   */
   public String[] getValueField() {
     return valueField;
   }
 
-  /** @param valueField The valueField to set. */
+  /**
+   * @param valueField The valueField to set.
+   */
   public void setValueField(String[] valueField) {
     this.valueField = valueField;
   }
@@ -244,16 +260,6 @@ public class MemoryGroupByMeta extends BaseTransformMeta
     return retval;
   }
 
-  @Override
-  public MemoryGroupBy createTransform(
-      TransformMeta transformMeta,
-      MemoryGroupByData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new MemoryGroupBy(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   private void readData(Node transformNode) throws HopXmlException {
     try {
       Node groupn = XmlHandler.getSubNode(transformNode, "group");
@@ -343,11 +349,6 @@ public class MemoryGroupByMeta extends BaseTransformMeta
       TransformMeta nextTransform,
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
-    // Check compatibility mode
-    boolean compatibilityMode =
-        ValueMetaBase.convertStringToBoolean(
-            variables.getVariable(
-                Const.HOP_COMPATIBILITY_MEMORY_GROUP_BY_SUM_AVERAGE_RETURN_NUMBER_TYPE, "N"));
 
     // re-assemble a new row of metadata
     //
@@ -392,7 +393,7 @@ public class MemoryGroupByMeta extends BaseTransformMeta
             break;
           case TYPE_GROUP_SUM:
           case TYPE_GROUP_AVERAGE:
-            if (!compatibilityMode && subj.isNumeric()) {
+            if (subj.isNumeric()) {
               valueType = subj.getType();
             } else {
               valueType = IValueMeta.TYPE_NUMBER;
@@ -511,17 +512,16 @@ public class MemoryGroupByMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public MemoryGroupByData getTransformData() {
-    return new MemoryGroupByData();
-  }
-
-  /** @return the alwaysGivingBackOneRow */
+  /**
+   * @return the alwaysGivingBackOneRow
+   */
   public boolean isAlwaysGivingBackOneRow() {
     return alwaysGivingBackOneRow;
   }
 
-  /** @param alwaysGivingBackOneRow the alwaysGivingBackOneRow to set */
+  /**
+   * @param alwaysGivingBackOneRow the alwaysGivingBackOneRow to set
+   */
   public void setAlwaysGivingBackOneRow(boolean alwaysGivingBackOneRow) {
     this.alwaysGivingBackOneRow = alwaysGivingBackOneRow;
   }
