@@ -16,7 +16,6 @@
  */
 package org.apache.hop.pipeline.transforms.memgroupby;
 
-import org.apache.hop.core.Const;
 import org.apache.hop.core.HopEnvironment;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.plugins.PluginRegistry;
@@ -34,7 +33,10 @@ import org.junit.Before;
 import org.junit.ClassRule;
 import org.junit.Test;
 
-import java.util.*;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 
 import static org.junit.Assert.*;
 
@@ -337,16 +339,6 @@ public class MemoryGroupByMetaTest implements IInitializer<MemoryGroupByMeta> {
     assertTrue(rm.indexOfValue("Average(Date)") >= 0);
     assertEquals(
         IValueMeta.TYPE_NUMBER, rm.getValueMeta(rm.indexOfValue("Average(Date)")).getType());
-
-    // Test Compatibility
-    rm = getInputRowMeta();
-    vars.setVariable(Const.HOP_COMPATIBILITY_MEMORY_GROUP_BY_SUM_AVERAGE_RETURN_NUMBER_TYPE, "Y");
-    meta.getFields(rm, transformName, null, null, vars, null);
-    assertNotNull(rm);
-    assertEquals(26, rm.size());
-    assertTrue(rm.indexOfValue("Average(Integer)") >= 0);
-    assertEquals(
-        IValueMeta.TYPE_NUMBER, rm.getValueMeta(rm.indexOfValue("Average(Integer)")).getType());
   }
 
   @Test
