@@ -32,10 +32,10 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelineMeta.PipelineType;
 import org.apache.hop.pipeline.transform.*;
-import org.apache.hop.pipeline.transform.errorhandling.IStream;
-import org.apache.hop.pipeline.transform.errorhandling.IStream.StreamType;
-import org.apache.hop.pipeline.transform.errorhandling.Stream;
-import org.apache.hop.pipeline.transform.errorhandling.StreamIcon;
+import org.apache.hop.pipeline.transform.stream.IStream;
+import org.apache.hop.pipeline.transform.stream.IStream.StreamType;
+import org.apache.hop.pipeline.transform.stream.Stream;
+import org.apache.hop.pipeline.transform.stream.StreamIcon;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -43,13 +43,12 @@ import java.util.List;
 @Transform(
     id = "MergeJoin",
     image = "mergejoin.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.MergeJoin",
-    description = "i18n::BaseTransform.TypeTooltipDesc.MergeJoin",
+    name = "i18n::MergeJoin.Name",
+    description = "i18n::MergeJoin.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Joins",
     keywords = "i18n::MergeJoinMeta.keyword",
     documentationUrl = "/pipeline/transforms/mergejoin.html")
-public class MergeJoinMeta extends BaseTransformMeta
-    implements ITransformMeta<MergeJoin, MergeJoinData> {
+public class MergeJoinMeta extends BaseTransformMeta<MergeJoin, MergeJoinData> {
   private static final Class<?> PKG = MergeJoinMeta.class; // For Translator
 
   public static final String[] joinTypes = {"INNER", "LEFT OUTER", "RIGHT OUTER", "FULL OUTER"};
@@ -97,16 +96,6 @@ public class MergeJoinMeta extends BaseTransformMeta
     return true;
   }
 
-  @Override
-  public MergeJoin createTransform(
-      TransformMeta transformMeta,
-      MergeJoinData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new MergeJoin(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   public MergeJoinMeta() {
     keyFields1 = new ArrayList<>();
     keyFields2 = new ArrayList<>();
@@ -194,11 +183,6 @@ public class MergeJoinMeta extends BaseTransformMeta
     return new MergeJoin(transformMeta, this, data, cnr, tr, pipeline);
   }
 
-  @Override
-  public MergeJoinData getTransformData() {
-    return new MergeJoinData();
-  }
-
   /**
    * Returns the Input/Output metadata for this transform. The generator transform only produces
    * output, does not accept input!
