@@ -37,10 +37,11 @@ import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.ISubPipelineAwareMeta;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineHopMeta;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.*;
+import org.apache.hop.pipeline.transform.BaseTransformMeta;
+import org.apache.hop.pipeline.transform.ITransformMetaChangeListener;
+import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
 import org.apache.hop.resource.ResourceEntry;
@@ -56,16 +57,16 @@ import java.util.Map.Entry;
 @Transform(
     id = "MetaInject",
     image = "GenericTransform.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.MetaInject",
-    description = "i18n::BaseTransform.TypeTooltipDesc.MetaInject",
+    name = "i18n::MetaInject.Name",
+    description = "i18n::MetaInject.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Transform",
     keywords = "i18n::MetaInjectMeta.keyword",
     documentationUrl = "/pipeline/transforms/metainject.html")
 @InjectionSupported(
     localizationPrefix = "MetaInject.Injection.",
     groups = {"SOURCE_OUTPUT_FIELDS", "MAPPING_FIELDS"})
-public class MetaInjectMeta extends BaseTransformMeta
-    implements ITransformMeta<MetaInject, MetaInjectData>,
+public class MetaInjectMeta extends BaseTransformMeta<MetaInject, MetaInjectData>
+    implements 
         ITransformMetaChangeListener,
         ISubPipelineAwareMeta {
 
@@ -280,11 +281,6 @@ public class MetaInjectMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public MetaInjectData getTransformData() {
-    return new MetaInjectData();
-  }
-
   public Map<TargetTransformAttribute, SourceTransformField> getTargetSourceMapping() {
     return targetSourceMapping;
   }
@@ -416,16 +412,6 @@ public class MetaInjectMeta extends BaseTransformMeta
     return true;
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      MetaInjectData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new MetaInject(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   @Override
   public boolean excludeFromRowLayoutVerification() {
     return true;
