@@ -23,12 +23,10 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 /** Business logic for the NumberRange */
-public class NumberRange extends BaseTransform<NumberRangeMeta, NumberRangeData>
-    implements ITransform<NumberRangeMeta, NumberRangeData> {
+public class NumberRange extends BaseTransform<NumberRangeMeta, NumberRangeData> {
   private static final Class<?> PKG = NumberRangeMeta.class; // For Translator
 
   private NumberRangeSet numberRange;
