@@ -32,10 +32,8 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.DatabaseImpact;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.ArrayList;
@@ -49,8 +47,7 @@ import java.util.List;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Bulk",
     keywords = "i18n::PGBulkLoaderMeta.keyword",
     documentationUrl = "/pipeline/transforms/postgresbulkloader.html")
-public class PGBulkLoaderMeta extends BaseTransformMeta
-    implements ITransformMeta<PGBulkLoader, PGBulkLoaderData>,
+public class PGBulkLoaderMeta extends BaseTransformMeta<PGBulkLoader, PGBulkLoaderData> implements
         IProvidesDatabaseConnectionInformation {
 
   private static final Class<?> PKG = PGBulkLoaderMeta.class; // For Translator
@@ -421,21 +418,6 @@ public class PGBulkLoaderMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public PGBulkLoader createTransform(
-      TransformMeta transformMeta,
-      PGBulkLoaderData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new PGBulkLoader(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public PGBulkLoaderData getTransformData() {
-    return new PGBulkLoaderData();
-  }
-
   @Override
   public IRowMeta getRequiredFields(IVariables variables) throws HopException {
     String realTableName = variables.resolve(tableName);
