@@ -35,7 +35,6 @@ import org.apache.hop.pipeline.config.PipelineRunConfiguration;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.ConstUi;
-import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterMappingDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
@@ -129,6 +128,9 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
 
   private boolean gotPreviousFields = false;
 
+  private final int middle = props.getMiddlePct();
+  private final int margin = props.getMargin();
+
   public PipelineExecutorDialog(
       Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
     super(parent, variables, (BaseTransformMeta) in, tr, sname);
@@ -155,8 +157,6 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
 
     ModifyListener lsMod = e -> pipelineExecutorMeta.setChanged();
 
-    int margin = props.getMargin();
-
     Label wicon = new Label(shell, SWT.RIGHT);
     wicon.setImage(getImage());
     FormData fdlicon = new FormData();
@@ -181,7 +181,8 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     props.setLook(wlTransformName);
     fdlTransformName = new FormData();
     fdlTransformName.left = new FormAttachment(0, 0);
-    fdlTransformName.top = new FormAttachment(0, 0);
+    fdlTransformName.top = new FormAttachment(wicon, 0, SWT.CENTER);
+    fdlTransformName.right = new FormAttachment(middle, -margin);
     wlTransformName.setLayoutData(fdlTransformName);
 
     wTransformName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
@@ -189,24 +190,24 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     props.setLook(wTransformName);
     fdTransformName = new FormData();
     fdTransformName.right = new FormAttachment(wicon, -5);
-    fdTransformName.left = new FormAttachment(0, 0);
-    fdTransformName.top = new FormAttachment(wlTransformName, 5);
+    fdTransformName.left = new FormAttachment(middle, margin);
+    fdTransformName.top = new FormAttachment(wlTransformName, 0, SWT.CENTER);
     wTransformName.setLayoutData(fdTransformName);
 
     Label spacer = new Label(shell, SWT.HORIZONTAL | SWT.SEPARATOR);
     FormData fdSpacer = new FormData();
     fdSpacer.left = new FormAttachment(0, 0);
-    fdSpacer.top = new FormAttachment(wTransformName, 15);
+    fdSpacer.top = new FormAttachment(wicon, 0);
     fdSpacer.right = new FormAttachment(100, 0);
     spacer.setLayoutData(fdSpacer);
 
-    wlPath = new Label(shell, SWT.LEFT);
+    wlPath = new Label(shell, SWT.RIGHT);
     props.setLook(wlPath);
     wlPath.setText(BaseMessages.getString(PKG, "PipelineExecutorDialog.Pipeline.Label"));
     FormData fdlTransformation = new FormData();
     fdlTransformation.left = new FormAttachment(0, 0);
     fdlTransformation.top = new FormAttachment(spacer, 20);
-    fdlTransformation.right = new FormAttachment(50, 0);
+    fdlTransformation.right = new FormAttachment(middle, -margin);
     wlPath.setLayoutData(fdlTransformation);
 
     Button wbBrowse = new Button(shell, SWT.PUSH);
@@ -214,16 +215,16 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     wbBrowse.setText(BaseMessages.getString(PKG, "PipelineExecutorDialog.Browse.Label"));
     FormData fdBrowse = new FormData();
     fdBrowse.right = new FormAttachment(100, 0);
-    fdBrowse.top = new FormAttachment(wlPath, Const.isOSX() ? 0 : 5);
+    fdBrowse.top = new FormAttachment(wlPath, 0, SWT.CENTER);
     wbBrowse.setLayoutData(fdBrowse);
     wbBrowse.addListener(SWT.Selection, e -> selectPipelineFile());
 
     wPath = new TextVar(variables, shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wPath);
     FormData fdTransformation = new FormData();
-    fdTransformation.left = new FormAttachment(0, 0);
-    fdTransformation.top = new FormAttachment(wlPath, 5);
-    fdTransformation.right = new FormAttachment(wbBrowse, -props.getMargin());
+    fdTransformation.left = new FormAttachment(middle, margin);
+    fdTransformation.top = new FormAttachment(wlPath, 0, SWT.CENTER);
+    fdTransformation.right = new FormAttachment(wbBrowse, -margin);
     wPath.setLayoutData(fdTransformation);
 
     wbPipelineNameInField = new Button(shell, SWT.CHECK);
@@ -231,7 +232,7 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     wbPipelineNameInField.setText(
         BaseMessages.getString(PKG, "PipelineExecutorDialog.PipelineNameInField.Label"));
     FormData fdPipelineNameInField = new FormData();
-    fdPipelineNameInField.left = new FormAttachment(0, 0);
+    fdPipelineNameInField.left = new FormAttachment(middle, margin);
     fdPipelineNameInField.top = new FormAttachment(wPath, margin);
     wbPipelineNameInField.setLayoutData(fdPipelineNameInField);
     wbPipelineNameInField.addSelectionListener(
@@ -244,13 +245,13 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
         });
 
     // FileNameField Line
-    wlPipelineNameField = new Label(shell, SWT.LEFT);
+    wlPipelineNameField = new Label(shell, SWT.RIGHT);
     wlPipelineNameField.setText(
         BaseMessages.getString(PKG, "PipelineExecutorDialog.PipelineNameField.Label"));
     props.setLook(wlPipelineNameField);
     FormData fdlPipelineNameField = new FormData();
     fdlPipelineNameField.left = new FormAttachment(0, 0);
-    fdlPipelineNameField.right = new FormAttachment(50, 0);
+    fdlPipelineNameField.right = new FormAttachment(middle, -margin);
     fdlPipelineNameField.top = new FormAttachment(wbPipelineNameInField, margin);
     wlPipelineNameField.setLayoutData(fdlPipelineNameField);
 
@@ -258,8 +259,8 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     props.setLook(wPipelineNameField);
     wPipelineNameField.addModifyListener(lsMod);
     FormData fdPipelineNameField = new FormData();
-    fdPipelineNameField.left = new FormAttachment(0, 0);
-    fdPipelineNameField.top = new FormAttachment(wlPipelineNameField, margin);
+    fdPipelineNameField.left = new FormAttachment(middle, margin);
+    fdPipelineNameField.top = new FormAttachment(wlPipelineNameField, 0, SWT.CENTER);
     fdPipelineNameField.right = new FormAttachment(100, 0);
     wPipelineNameField.setLayoutData(fdPipelineNameField);
     wPipelineNameField.setEnabled(false);
@@ -279,22 +280,21 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
         });
     /* End */
 
-    wlRunConfiguration = new Label(shell, SWT.LEFT);
+    wlRunConfiguration = new Label(shell, SWT.RIGHT);
     wlRunConfiguration.setText(
         BaseMessages.getString(PKG, "PipelineExecutorDialog.RunConfiguration.Label"));
     props.setLook(wlRunConfiguration);
     FormData fdlRunConfiguration = new FormData();
     fdlRunConfiguration.left = new FormAttachment(0, 0);
-    fdlRunConfiguration.top =
-        new FormAttachment(wPipelineNameField, PropsUi.getInstance().getMargin());
-    fdlRunConfiguration.right = new FormAttachment(50, 0);
+    fdlRunConfiguration.top = new FormAttachment(wPipelineNameField, margin);
+    fdlRunConfiguration.right = new FormAttachment(middle, -margin);
     wlRunConfiguration.setLayoutData(fdlRunConfiguration);
 
     wRunConfiguration = new ComboVar(variables, shell, SWT.LEFT | SWT.BORDER);
     props.setLook(wlRunConfiguration);
     FormData fdRunConfiguration = new FormData();
-    fdRunConfiguration.left = new FormAttachment(0, 0);
-    fdRunConfiguration.top = new FormAttachment(wlRunConfiguration, props.getMargin());
+    fdRunConfiguration.left = new FormAttachment(middle, margin);
+    fdRunConfiguration.top = new FormAttachment(wlRunConfiguration, 0, SWT.CENTER);
     fdRunConfiguration.right = new FormAttachment(100, 0);
     wRunConfiguration.setLayoutData(fdRunConfiguration);
     props.setLook(wRunConfiguration);
@@ -796,14 +796,15 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     FormData fdlGroupSize = new FormData();
     fdlGroupSize.top = new FormAttachment(0, 0);
     fdlGroupSize.left = new FormAttachment(0, 0);
+    fdlGroupSize.right = new FormAttachment(middle, -margin);
     wlGroupSize.setLayoutData(fdlGroupSize);
 
     wGroupSize = new TextVar(variables, wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wGroupSize);
     FormData fdGroupSize = new FormData();
-    fdGroupSize.width = 250;
-    fdGroupSize.top = new FormAttachment(wlGroupSize, 5);
-    fdGroupSize.left = new FormAttachment(0, 0);
+    fdGroupSize.right = new FormAttachment(100);
+    fdGroupSize.top = new FormAttachment(wlGroupSize, 0, SWT.CENTER);
+    fdGroupSize.left = new FormAttachment(middle, margin);
     wGroupSize.setLayoutData(fdGroupSize);
     // Enable/Disable fields base on the size of the group
     wGroupSize.addListener(SWT.Modify, e -> setFlags());
@@ -816,14 +817,15 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     FormData fdlGroupField = new FormData();
     fdlGroupField.top = new FormAttachment(wGroupSize, 10);
     fdlGroupField.left = new FormAttachment(0, 0);
+    fdlGroupField.right = new FormAttachment(middle, -margin);
     wlGroupField.setLayoutData(fdlGroupField);
 
     wGroupField = new CCombo(wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wGroupField);
     FormData fdGroupField = new FormData();
-    fdGroupField.width = 250;
-    fdGroupField.top = new FormAttachment(wlGroupField, 5);
-    fdGroupField.left = new FormAttachment(0, 0);
+    fdGroupField.right = new FormAttachment(100);
+    fdGroupField.top = new FormAttachment(wlGroupField, 0, SWT.CENTER);
+    fdGroupField.left = new FormAttachment(middle, margin);
     wGroupField.setLayoutData(fdGroupField);
     // Enable/Disable widgets when this field changes
     wGroupField.addListener(SWT.Modify, e -> setFlags());
@@ -835,15 +837,16 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     wlGroupTime.setText(BaseMessages.getString(PKG, "PipelineExecutorDialog.GroupTime.Label"));
     FormData fdlGroupTime = new FormData();
     fdlGroupTime.top = new FormAttachment(wGroupField, 10);
-    fdlGroupTime.left = new FormAttachment(0, 0); // First one in the left
+    fdlGroupTime.left = new FormAttachment(0, 0);
+    fdlGroupTime.right = new FormAttachment(middle, -margin);
     wlGroupTime.setLayoutData(fdlGroupTime);
 
     wGroupTime = new TextVar(variables, wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wGroupTime);
     FormData fdGroupTime = new FormData();
-    fdGroupTime.width = 250;
-    fdGroupTime.top = new FormAttachment(wlGroupTime, 5);
-    fdGroupTime.left = new FormAttachment(0, 0);
+    fdGroupTime.right = new FormAttachment(100);
+    fdGroupTime.top = new FormAttachment(wlGroupTime,  0, SWT.CENTER);
+    fdGroupTime.left = new FormAttachment(wlGroupTime, margin);
     wGroupTime.setLayoutData(fdGroupTime);
 
     wTab.setControl(wInputComposite);
@@ -875,15 +878,15 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
         BaseMessages.getString(PKG, "PipelineExecutorDialog.ExecutionResultTarget.Label"));
     FormData fdlExecutionResultTarget = new FormData();
     fdlExecutionResultTarget.top = new FormAttachment(0, 0);
-    fdlExecutionResultTarget.left = new FormAttachment(0, 0); // First one in the left
+    fdlExecutionResultTarget.right = new FormAttachment(middle, -margin);
     wlExecutionResultTarget.setLayoutData(fdlExecutionResultTarget);
 
     wExecutionResultTarget = new CCombo(wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wExecutionResultTarget);
     FormData fdExecutionResultTarget = new FormData();
-    fdExecutionResultTarget.width = 250;
-    fdExecutionResultTarget.top = new FormAttachment(wlExecutionResultTarget, 5);
-    fdExecutionResultTarget.left = new FormAttachment(0, 0); // To the right
+    fdExecutionResultTarget.right = new FormAttachment(100);
+    fdExecutionResultTarget.top = new FormAttachment(wlExecutionResultTarget, 0, SWT.CENTER);
+    fdExecutionResultTarget.left = new FormAttachment(middle, margin);
     wExecutionResultTarget.setLayoutData(fdExecutionResultTarget);
 
     ColumnInfo[] executionResultColumns =
@@ -1021,15 +1024,16 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
         BaseMessages.getString(PKG, "PipelineExecutorDialog.ResultFilesTarget.Label"));
     FormData fdlResultFilesTarget = new FormData();
     fdlResultFilesTarget.top = new FormAttachment(0, 0);
-    fdlResultFilesTarget.left = new FormAttachment(0, 0); // First one in the left
+    fdlResultFilesTarget.left = new FormAttachment(0, 0);
+    fdlResultFilesTarget.right = new FormAttachment(middle, -margin);
     wlResultFilesTarget.setLayoutData(fdlResultFilesTarget);
 
     wResultFilesTarget = new CCombo(wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wResultFilesTarget);
     FormData fdResultFilesTarget = new FormData();
     fdResultFilesTarget.width = 250;
-    fdResultFilesTarget.top = new FormAttachment(wlResultFilesTarget, 5);
-    fdResultFilesTarget.left = new FormAttachment(0, 0); // To the right
+    fdResultFilesTarget.top = new FormAttachment(wlResultFilesTarget, 0, SWT.CENTER);
+    fdResultFilesTarget.left = new FormAttachment(wlResultFilesTarget, margin);
     wResultFilesTarget.setLayoutData(fdResultFilesTarget);
 
     // ResultFileNameField
@@ -1039,8 +1043,9 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     wlResultFileNameField.setText(
         BaseMessages.getString(PKG, "PipelineExecutorDialog.ResultFileNameField.Label"));
     FormData fdlResultFileNameField = new FormData();
-    fdlResultFileNameField.top = new FormAttachment(wResultFilesTarget, 10);
-    fdlResultFileNameField.left = new FormAttachment(0, 0); // First one in the left
+    fdlResultFileNameField.top = new FormAttachment(wResultFilesTarget, margin * 2);
+    fdlResultFileNameField.left = new FormAttachment(0, 0);
+    fdlResultFileNameField.right = new FormAttachment(middle, -margin);
     wlResultFileNameField.setLayoutData(fdlResultFileNameField);
 
     wResultFileNameField =
@@ -1048,8 +1053,9 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
     props.setLook(wResultFileNameField);
     FormData fdResultFileNameField = new FormData();
     fdResultFileNameField.width = 250;
-    fdResultFileNameField.top = new FormAttachment(wlResultFileNameField, 5);
-    fdResultFileNameField.left = new FormAttachment(0, 0); // To the right
+    fdResultFileNameField.top = new FormAttachment(wlResultFileNameField, 0, SWT.CENTER);
+    fdResultFileNameField.left = new FormAttachment(wlResultFileNameField, margin);
+    fdResultFileNameField.right = new FormAttachment(100);
     wResultFileNameField.setLayoutData(fdResultFileNameField);
 
     wInputComposite.pack();
@@ -1089,15 +1095,16 @@ public class PipelineExecutorDialog extends BaseTransformDialog implements ITran
         BaseMessages.getString(PKG, "PipelineExecutorDialog.OutputRowsSource.Label"));
     FormData fdlResultRowsTarget = new FormData();
     fdlResultRowsTarget.top = new FormAttachment(0, 0);
-    fdlResultRowsTarget.left = new FormAttachment(0, 0); // First one in the left
+    fdlResultRowsTarget.left = new FormAttachment(0, 0);
+    fdlResultRowsTarget.right = new FormAttachment(middle, -margin);
     wlResultRowsTarget.setLayoutData(fdlResultRowsTarget);
 
     wOutputRowsSource = new CCombo(wInputComposite, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     props.setLook(wOutputRowsSource);
     FormData fdResultRowsTarget = new FormData();
-    fdResultRowsTarget.width = 250;
-    fdResultRowsTarget.top = new FormAttachment(wlResultRowsTarget, 5);
-    fdResultRowsTarget.left = new FormAttachment(0, 0); // To the right
+    fdResultRowsTarget.right = new FormAttachment(100);
+    fdResultRowsTarget.top = new FormAttachment(wlResultRowsTarget, 0, SWT.CENTER);
+    fdResultRowsTarget.left = new FormAttachment(middle, margin);
     wOutputRowsSource.setLayoutData(fdResultRowsTarget);
 
     Label wlOutputFields = new Label(wInputComposite, SWT.NONE);
