@@ -29,11 +29,9 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
-public class ProcessFiles extends BaseTransform<ProcessFilesMeta, ProcessFilesData>
-    implements ITransform<ProcessFilesMeta, ProcessFilesData> {
+public class ProcessFiles extends BaseTransform<ProcessFilesMeta, ProcessFilesData> {
   private static final Class<?> PKG = ProcessFilesMeta.class; // For Translator
 
   public ProcessFiles(
