@@ -29,7 +29,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.HashSet;
@@ -38,8 +37,8 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 /** Search and replace in string. */
-public class ReplaceString extends BaseTransform<ReplaceStringMeta, ReplaceStringData>
-    implements ITransform<ReplaceStringMeta, ReplaceStringData> {
+public class ReplaceString extends BaseTransform<ReplaceStringMeta, ReplaceStringData> {
+
   private static final Class<?> PKG = ReplaceStringMeta.class; // For Translator
 
   public ReplaceString(
