@@ -25,7 +25,6 @@ import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.Calendar;
@@ -34,8 +33,7 @@ import java.util.List;
 import java.util.Locale;
 
 /** Get information from the System or the supervising pipeline. */
-public class SystemData extends BaseTransform<SystemDataMeta, SystemDataData>
-    implements ITransform<SystemDataMeta, SystemDataData> {
+public class SystemData extends BaseTransform<SystemDataMeta, SystemDataData> {
 
   public SystemData(
       TransformMeta transformMeta,
