@@ -34,7 +34,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.sql.PreparedStatement;
@@ -44,8 +43,7 @@ import java.util.Date;
 import java.util.List;
 
 /** Writes rows to a database table. */
-public class TableOutput extends BaseTransform<TableOutputMeta, TableOutputData>
-    implements ITransform<TableOutputMeta, TableOutputData> {
+public class TableOutput extends BaseTransform<TableOutputMeta, TableOutputData> {
 
   private static final Class<?> PKG = TableOutputMeta.class; // For Translator
 
@@ -490,13 +488,13 @@ public class TableOutput extends BaseTransform<TableOutputMeta, TableOutputData>
         // For these situations we can use savepoints to help out.
         //
         data.useSafePoints =
-            data.databaseMeta.getIDatabase().useSafePoints()
+            data.databaseMeta.getIDatabase().isUseSafePoints()
                 && getTransformMeta().isDoingErrorHandling();
 
         // Get the boolean that indicates whether or not we can/should release
         // savepoints during data load.
         //
-        data.releaseSavepoint = dbInterface.releaseSavepoint();
+        data.releaseSavepoint = dbInterface.isReleaseSavepoint();
 
         // Disable batch mode in case
         // - we use an unlimited commit size
@@ -515,7 +513,7 @@ public class TableOutput extends BaseTransform<TableOutputMeta, TableOutputData>
         // incorrectly processed rows.
         //
         if (getTransformMeta().isDoingErrorHandling()
-            && !dbInterface.supportsErrorHandlingOnBatchUpdates()) {
+            && !dbInterface.IsSupportsErrorHandlingOnBatchUpdates()) {
           log.logBasic(
               BaseMessages.getString(
                   PKG, "TableOutput.Warning.ErrorHandlingIsNotFullySupportedWithBatchProcessing"));
