@@ -34,9 +34,10 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.DatabaseImpact;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.*;
+import org.apache.hop.pipeline.transform.BaseTransformMeta;
+import org.apache.hop.pipeline.transform.ITransformData;
+import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -45,13 +46,12 @@ import java.util.List;
 @Transform(
     id = "TableOutput",
     image = "tableoutput.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.TableOutput",
-    description = "i18n::BaseTransform.TypeTooltipDesc.TableOutput",
+    name = "i18n::TableOutput.Name",
+    description = "i18n::TableOutput.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Output",
     keywords = "i18n::TableOutputMeta.keyword",
     documentationUrl = "/pipeline/transforms/tableoutput.html")
-public class TableOutputMeta extends BaseTransformMeta
-    implements ITransformMeta<TableOutput, TableOutputData>, IProvidesModelerMeta {
+public class TableOutputMeta extends BaseTransformMeta<TableOutput, TableOutputData> implements IProvidesModelerMeta {
   private static final Class<?> PKG = TableOutputMeta.class; // For Translator
 
   private static final String PARTION_PER_DAY = "DAY";
@@ -672,21 +672,6 @@ public class TableOutputMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      TableOutputData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new TableOutput(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public TableOutputData getTransformData() {
-    return new TableOutputData();
-  }
-
   @Override
   public void analyseImpact(
       IVariables variables,
