@@ -41,11 +41,8 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransform;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
@@ -60,18 +57,17 @@ import java.util.Locale;
 import java.util.Map;
 
 /** @deprecated replaced by implementation in the ...transforms.fileinput.text package */
-@Deprecated
+@Deprecated(since="2.0")
 @Transform(
     id = "TextFileInput",
     image = "textfileinput.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.TextFileInput",
-    description = "i18n::BaseTransform.TypeTooltipDesc.TextFileInput",
+    name = "i18n::TextFileInput.Name",
+    description = "i18n::TextFileInput.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Input",
     keywords = "i18n::TextFileInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/textfileinput.html")
-public class TextFileInputMeta extends BaseTransformMeta
-    implements ITransformMeta<TextFileInput, TextFileInputData>,
-        IInputFileMeta<TextFileInput, TextFileInputData> {
+public class TextFileInputMeta extends BaseTransformMeta<TextFileInput, TextFileInputData>
+implements IInputFileMeta {
 
   private static final Class<?> PKG = TextFileInputMeta.class; // For Translator
 
@@ -1338,21 +1334,6 @@ public class TextFileInputMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      TextFileInputData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new TextFileInput(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public TextFileInputData getTransformData() {
-    return new TextFileInputData();
-  }
-
   /** @return Returns the escapeCharacter. */
   @Override
   public String getEscapeCharacter() {
