@@ -43,9 +43,7 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.common.ICsvInputAwareMeta;
 import org.apache.hop.pipeline.transforms.file.BaseFileField;
@@ -65,8 +63,8 @@ import java.util.Map;
 @Transform(
     id = "TextFileInput2",
     image = "textfileinput.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.TextFileInput",
-    description = "i18n::BaseTransform.TypeTooltipDesc.TextFileInput",
+    name = "i18n::TextFileInput.Name",
+    description = "i18n::TextFileInput.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Input",
     keywords = "i18n::TextFileInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/textfileinput.html")
@@ -75,12 +73,12 @@ import java.util.Map;
     groups = {"FILENAME_LINES", "FIELDS", "FILTERS"})
 public class TextFileInputMeta
     extends BaseFileInputMeta<
+        TextFileInput,
+        TextFileInputData,
         BaseFileInputAdditionalField,
         BaseFileInputFiles,
-        BaseFileField,
-        TextFileInput,
-        TextFileInputData>
-    implements ITransformMeta<TextFileInput, TextFileInputData>, ICsvInputAwareMeta {
+        BaseFileField>
+    implements ICsvInputAwareMeta {
   private static final Class<?> PKG = TextFileInputMeta.class; // For Translator
 
   private static final String STRING_BASE64_PREFIX = "Base64: ";
@@ -1003,22 +1001,6 @@ public class TextFileInputMeta
     }
   }
 
-  @Override
-  public TextFileInput createTransform(
-      TransformMeta transformMeta,
-      TextFileInputData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new TextFileInput(
-        transformMeta, this, (TextFileInputData) data, copyNr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public TextFileInputData getTransformData() {
-    return new TextFileInputData();
-  }
-
   public String getErrorCountField() {
     return errorCountField;
   }
