@@ -38,7 +38,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.io.BufferedOutputStream;
@@ -51,19 +50,13 @@ import java.util.List;
 
 /** Converts input rows to text and then writes this text to one or more files. */
 public class TextFileOutput<Meta extends TextFileOutputMeta, Data extends TextFileOutputData>
-    extends BaseTransform<Meta, Data> implements ITransform<Meta, Data> {
+    extends BaseTransform<Meta, Data> {
 
   private static final Class<?> PKG = TextFileOutputMeta.class; // For Translator
 
   private static final String FILE_COMPRESSION_TYPE_NONE =
       TextFileOutputMeta.fileCompressionTypeCodes[TextFileOutputMeta.FILE_COMPRESSION_TYPE_NONE];
-  private static final boolean COMPATIBILITY_APPEND_NO_HEADER =
-      "Y"
-          .equals(
-              Const.NVL(
-                  System.getProperty(Const.HOP_COMPATIBILITY_TEXT_FILE_OUTPUT_APPEND_NO_HEADER),
-                  "N"));
-
+  
   public TextFileOutput(
       TransformMeta transformMeta,
       Meta meta,
@@ -323,7 +316,7 @@ public class TextFileOutput<Meta extends TextFileOutputMeta, Data extends TextFi
     isWriteHeader &=
         writingToFileForFirstTime
             && (!meta.isFileAppended()
-                || (!COMPATIBILITY_APPEND_NO_HEADER && !isFileExists(filename)));
+                || (!isFileExists(filename)));
     return isWriteHeader;
   }
 
