@@ -73,7 +73,7 @@ public class TextFileOutputTest {
   @BeforeClass
   public static void setUpBeforeClass() throws Exception {
     PluginRegistry.addPluginType(CompressionPluginType.getInstance());
-    PluginRegistry.init(false);
+    PluginRegistry.init();
   }
 
   @AfterClass
