@@ -35,7 +35,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.webservices.wsdl.*;
 import org.apache.http.*;
@@ -78,8 +77,7 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.*;
 
-public class WebService extends BaseTransform<WebServiceMeta, WebServiceData>
-    implements ITransform<WebServiceMeta, WebServiceData> {
+public class WebService extends BaseTransform<WebServiceMeta, WebServiceData> {
   private static final Class<?> PKG = WebServiceMeta.class; // For Translator
 
   public static final String NS_PREFIX = "ns";
@@ -129,8 +127,6 @@ public class WebService extends BaseTransform<WebServiceMeta, WebServiceData>
 
   @Override
   public boolean processRow() throws HopException {
-    meta = (WebServiceMeta) meta;
-
     // if a URL is not specified, throw an exception
     if (Utils.isEmpty(meta.getUrl())) {
       throw new HopTransformException(
@@ -144,7 +140,6 @@ public class WebService extends BaseTransform<WebServiceMeta, WebServiceData>
               PKG, "WebServices.ERROR0015.OperationNotSelected", getTransformName()));
     }
 
-    data = (WebServiceData) data;
     Object[] vCurrentRow = getRow();
 
     if (first) {
