@@ -37,14 +37,16 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelineMeta.PipelineType;
-import org.apache.hop.pipeline.transform.*;
-import org.apache.hop.pipeline.transform.errorhandling.IStream;
-import org.apache.hop.pipeline.transform.errorhandling.IStream.StreamType;
-import org.apache.hop.pipeline.transform.errorhandling.Stream;
-import org.apache.hop.pipeline.transform.errorhandling.StreamIcon;
+import org.apache.hop.pipeline.transform.BaseTransformMeta;
+import org.apache.hop.pipeline.transform.ITransformIOMeta;
+import org.apache.hop.pipeline.transform.TransformIOMeta;
+import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.pipeline.transform.stream.IStream;
+import org.apache.hop.pipeline.transform.stream.IStream.StreamType;
+import org.apache.hop.pipeline.transform.stream.Stream;
+import org.apache.hop.pipeline.transform.stream.StreamIcon;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
 import org.apache.hop.resource.ResourceEntry;
@@ -66,9 +68,7 @@ import java.util.Map;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Flow",
     documentationUrl = "/pipeline/transforms/workflowexecutor.html",
     keywords = "i18n::WorkflowExecutorMeta.keyword")
-public class WorkflowExecutorMeta extends BaseTransformMeta
-    implements ITransformMeta<WorkflowExecutor, WorkflowExecutorData> {
-
+public class WorkflowExecutorMeta extends BaseTransformMeta<WorkflowExecutor, WorkflowExecutorData> {
   private static final Class<?> PKG = WorkflowExecutorMeta.class; // For Translator
 
   /** The name of the workflow run configuration to execute with */
@@ -621,16 +621,6 @@ public class WorkflowExecutorMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      WorkflowExecutorData data,
-      int cnr,
-      PipelineMeta tr,
-      Pipeline pipeline) {
-    return new WorkflowExecutor(transformMeta, this, data, cnr, tr, pipeline);
-  }
-
   @Override
   public List<ResourceReference> getResourceDependencies(
       IVariables variables, TransformMeta transformMeta) {
@@ -713,11 +703,6 @@ public class WorkflowExecutorMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public WorkflowExecutorData getTransformData() {
-    return new WorkflowExecutorData();
-  }
-
   @Override
   public ITransformIOMeta getTransformIOMeta() {
     ITransformIOMeta ioMeta = super.getTransformIOMeta(false);
