@@ -28,7 +28,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import javax.xml.transform.Source;
@@ -41,8 +40,8 @@ import java.io.StringWriter;
 import java.util.Properties;
 
 /** Executes a XSL Transform on the values in the input stream. */
-public class Xslt extends BaseTransform<XsltMeta, XsltData>
-    implements ITransform<XsltMeta, XsltData> {
+public class Xslt extends BaseTransform<XsltMeta, XsltData> {
+
   private static final Class<?> PKG = XsltMeta.class; // For Translator
 
   static final String JAXP_SCHEMA_LANGUAGE =
