@@ -883,6 +883,8 @@ public class ExplorerPerspective implements IHopPerspective {
       id = TOOLBAR_ITEM_REFRESH,
       toolTip = "i18n::ExplorerPerspective.ToolbarElement.Refresh.Tooltip",
       image = "ui/images/refresh.svg")
+  @GuiKeyboardShortcut(key = SWT.F5)
+  @GuiOsxKeyboardShortcut(key = SWT.F5)  
   public void refresh() {
     try {
       determineRootFolderName(hopGui);
@@ -1055,7 +1057,6 @@ public class ExplorerPerspective implements IHopPerspective {
 
   public void updateSelection() {
 
-    String objectKey;
     TreeItemFolder tif = null;
 
     if (tree.getSelectionCount() > 0) {
